@@ -22,11 +22,9 @@ from qtpy.QtWidgets import QMenu, QMessageBox
 # Local imports
 from spyder.config.base import _, get_home_dir
 from spyder.plugins import SpyderPluginMixin
-from spyder.py3compat import is_text_string
-from spyder.utils import encoding
+from spyder.py3compat import is_text_string, getcwd
 from spyder.utils import icon_manager as ima
 from spyder.utils.qthelpers import add_actions, create_action, MENU_SEPARATOR
-from spyder.utils.misc import getcwd_or_home
 from spyder.widgets.projects.explorer import ProjectExplorerWidget
 from spyder.widgets.projects.projectdialog import ProjectDialog
 from spyder.widgets.projects import EmptyProject
@@ -37,8 +35,9 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
 
     CONF_SECTION = 'project_explorer'
 
+    open_terminal = Signal(str)
     open_interpreter = Signal(str)
-    sig_pythonpath_changed = Signal()
+    pythonpath_changed = Signal()
 
     # File operations
     create_module = Signal(str)
@@ -46,9 +45,7 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
     removed = Signal(str)
     removed_tree = Signal(str)
     renamed = Signal(str, str)
-    renamed_tree = Signal(str, str)
     redirect_stdio = Signal(bool)
-    run = Signal(str)
 
     # Project handling
     sig_project_created = Signal(object, object, object)
@@ -56,7 +53,7 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
     sig_project_closed = Signal(object)
     sig_new_file = Signal(str)
 
-    def __init__(self, parent=None, testing=False):
+    def __init__(self, parent=None):
         ProjectExplorerWidget.__init__(self, parent=parent,
                     name_filters=self.get_option('name_filters'),
                     show_all=self.get_option('show_all'),
@@ -70,12 +67,8 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
         self.editor = None
         self.workingdirectory = None
 
-        # For testing
-        self.testing = testing
-
         # Initialize plugin
-        if not self.testing:
-            self.initialize_plugin()
+        self.initialize_plugin()
         self.setup_project(self.get_active_project_path())
 
     #------ SpyderPluginWidget API ---------------------------------------------
@@ -133,13 +126,12 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
         self.main.pythonpath_changed()
         self.main.restore_scrollbar_position.connect(
                                                self.restore_scrollbar_position)
-        self.sig_pythonpath_changed.connect(self.main.pythonpath_changed)
+        self.pythonpath_changed.connect(self.main.pythonpath_changed)
         self.create_module.connect(self.editor.new)
         self.edit.connect(self.editor.load)
         self.removed.connect(self.editor.removed)
         self.removed_tree.connect(self.editor.removed_tree)
         self.renamed.connect(self.editor.renamed)
-        self.renamed_tree.connect(self.editor.renamed_tree)
         self.editor.set_projects(self)
         self.main.add_dockwidget(self)
 
@@ -151,14 +143,14 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
         self.sig_project_loaded.connect(
             lambda v: self.workingdirectory.chdir(v))
         self.sig_project_loaded.connect(
-            lambda v: self.main.set_window_title())
+            lambda v: self.main.update_window_title())
         self.sig_project_loaded.connect(
             lambda v: self.editor.setup_open_files())
         self.sig_project_loaded.connect(self.update_explorer)
         self.sig_project_closed[object].connect(
             lambda v: self.workingdirectory.chdir(self.get_last_working_dir()))
         self.sig_project_closed.connect(
-            lambda v: self.main.set_window_title())
+            lambda v: self.main.update_window_title())
         self.sig_project_closed.connect(
             lambda v: self.editor.setup_open_files())
         self.recent_project_menu.aboutToShow.connect(self.setup_menu_actions)
@@ -230,10 +222,10 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
         dlg.sig_project_creation_requested.connect(self._create_project)
         dlg.sig_project_creation_requested.connect(self.sig_project_created)
         if dlg.exec_():
-            if (active_project is None
-                    and self.get_option('visible_if_project_open')):
+            pass
+            if active_project is None:
                 self.show_explorer()
-            self.sig_pythonpath_changed.emit()
+            self.pythonpath_changed.emit()
             self.restart_consoles()
 
     def _create_project(self, path):
@@ -250,39 +242,29 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
             path = getexistingdirectory(parent=self,
                                         caption=_("Open project"),
                                         basedir=basedir)
-            path = encoding.to_unicode_from_fs(path)
             if not self.is_valid_project(path):
                 if path:
                     QMessageBox.critical(self, _('Error'),
                                 _("<b>%s</b> is not a Spyder project!") % path)
                 return
-        else:
-            path = encoding.to_unicode_from_fs(path)
-
-        self.add_to_recent(path)
+            else:
+                self.add_to_recent(path)
 
         # A project was not open before
         if self.current_active_project is None:
-            if save_previous_files and self.editor is not None:
+            if save_previous_files:
                 self.editor.save_open_files()
-            if self.editor is not None:
-                self.editor.set_option('last_working_dir', getcwd_or_home())
-            if self.get_option('visible_if_project_open'):
-                self.show_explorer()
-        else:
-            # We are switching projects
-            if self.editor is not None:
-                self.set_project_filenames(self.editor.get_open_filenames())
+            self.editor.set_option('last_working_dir', getcwd())
+            self.show_explorer()
+        else: # we are switching projects
+            self.set_project_filenames(self.editor.get_open_filenames())
 
         self.current_active_project = EmptyProject(path)
         self.latest_project = EmptyProject(path)
         self.set_option('current_project_path', self.get_active_project_path())
-
-        if not self.testing:
-            self.setup_menu_actions()
+        self.setup_menu_actions()
         self.sig_project_loaded.emit(path)
-        self.sig_pythonpath_changed.emit()
-
+        self.pythonpath_changed.emit()
         if restart_consoles:
             self.restart_consoles()
 
@@ -293,26 +275,16 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
         """
         if self.current_active_project:
             path = self.current_active_project.root_path
+            self.set_project_filenames(self.editor.get_open_filenames())
             self.current_active_project = None
             self.set_option('current_project_path', None)
-
-            if not self.testing:
-                self.setup_menu_actions()
-
+            self.setup_menu_actions()
             self.sig_project_closed.emit(path)
-            self.sig_pythonpath_changed.emit()
-
-            if self.dockwidget is not None:
-                self.set_option('visible_if_project_open',
-                                self.dockwidget.isVisible())
-                self.dockwidget.close()
-
+            self.pythonpath_changed.emit()
+            self.dockwidget.close()
             self.clear()
             self.restart_consoles()
 
-            if self.editor is not None:
-                self.set_project_filenames(self.editor.get_open_filenames())
-
     def clear_recent_projects(self):
         """Clear the list of recent projects"""
         self.recent_projects = []
@@ -348,9 +320,7 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
 
     def set_project_filenames(self, recent_files):
         """Set the list of open file names in a project"""
-        if (self.current_active_project
-                and self.is_valid_project(
-                        self.current_active_project.root_path)):
+        if self.current_active_project:
             self.current_active_project.set_recent_files(recent_files)
 
     def get_active_project_path(self):
@@ -374,22 +344,14 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
 
     def get_last_working_dir(self):
         """Get the path of the last working directory"""
-        return self.editor.get_option('last_working_dir',
-                                      default=getcwd_or_home())
+        return self.editor.get_option('last_working_dir', default=getcwd())
 
     def save_config(self):
-        """
-        Save configuration: opened projects & tree widget state.
-
-        Also save whether dock widget is visible if a project is open.
-        """
+        """Save configuration: opened projects & tree widget state"""
         self.set_option('recent_projects', self.recent_projects)
         self.set_option('expanded_state', self.treewidget.get_expanded_state())
         self.set_option('scrollbar_position',
                         self.treewidget.get_scrollbar_position())
-        if self.current_active_project and self.dockwidget:
-            self.set_option('visible_if_project_open',
-                            self.dockwidget.isVisible())
 
     def load_config(self):
         """Load configuration: opened projects & tree widget state"""
@@ -414,15 +376,15 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
 
     def show_explorer(self):
         """Show the explorer"""
-        if self.dockwidget is not None:
-            if self.dockwidget.isHidden():
-                self.dockwidget.show()
-            self.dockwidget.raise_()
-            self.dockwidget.update()
+        if self.dockwidget.isHidden():
+            self.dockwidget.show()
+        self.dockwidget.raise_()
+        self.dockwidget.update()
 
     def restart_consoles(self):
         """Restart consoles when closing, opening and switching projects"""
-        if not self.testing and self.main.ipyconsole is not None:
+        self.main.extconsole.restart()
+        if self.main.ipyconsole:
             self.main.ipyconsole.restart()
 
     def is_valid_project(self, path):
