@@ -61,17 +61,6 @@ VALID_KEYS = [getattr(Qt, 'Key_{0}'.format(k)) for k in KEYSTRINGS+SINGLE_KEYS]
 VALID_ACCENT_CHARS = "ÁÉÍOÚáéíúóàèìòùÀÈÌÒÙâêîôûÂÊÎÔÛäëïöüÄËÏÖÜñÑ"
 VALID_FINDER_CHARS = "[A-Za-z\s{0}]".format(VALID_ACCENT_CHARS)
 
-BLACKLIST = {
-    'Shift+Del': _('Currently used to delete lines on editor')
-}
-
-if os.name == 'nt':
-    BLACKLIST['Alt+Backspace'] = _('We cannot support this '
-                                   'shortcut on Windows')
-
-BLACKLIST['Shift'] = _('Shortcuts that use Shift and another key'
-                       ' are unsupported')
-
 
 class CustomLineEdit(QLineEdit):
     """QLineEdit that filters its key press and release events."""
@@ -123,8 +112,7 @@ class ShortcutFinder(QLineEdit):
 
 
 # Error codes for the shortcut editor dialog
-(NO_WARNING, SEQUENCE_LENGTH, SEQUENCE_CONFLICT,
- INVALID_KEY, IN_BLACKLIST, SHIFT_BLACKLIST) = [0, 1, 2, 3, 4, 5]
+NO_WARNING, SEQUENCE_LENGTH, SEQUENCE_CONFLICT, INVALID_KEY = [0, 1, 2, 3]
 
 
 class ShortcutEditor(QDialog):
@@ -322,31 +310,13 @@ class ShortcutEditor(QDialog):
             tip = 'This shortcut is correct!'
         elif warning_type == SEQUENCE_CONFLICT:
             template = '<i>{0}<b>{1}</b></i>'
-            tip_title = _('The new shortcut conflicts with:') + '<br>'
+            tip_title = _('The new shorcut conflicts with:') + '<br>'
             tip_body = ''
             for s in conflicts:
                 tip_body += ' - {0}: {1}<br>'.format(s.context, s.name)
             tip_body = tip_body[:-4]  # Removing last <br>
             tip = template.format(tip_title, tip_body)
             warn = True
-        elif warning_type == IN_BLACKLIST:
-            template = '<i>{0}<b>{1}</b></i>'
-            tip_title = _('Forbidden key sequence!') + '<br>'
-            tip_body = ''
-            use = BLACKLIST[self.new_sequence]
-            if use is not None:
-                tip_body = use
-            tip = template.format(tip_title, tip_body)
-            warn = True
-        elif warning_type == SHIFT_BLACKLIST:
-            template = '<i>{0}<b>{1}</b></i>'
-            tip_title = _('Forbidden key sequence!') + '<br>'
-            tip_body = ''
-            use = BLACKLIST['Shift']
-            if use is not None:
-                tip_body = use
-            tip = template.format(tip_title, tip_body)
-            warn = True
         elif warning_type == SEQUENCE_LENGTH:
             # Sequences with 5 keysequences (i.e. Ctrl+1, Ctrl+2, Ctrl+3,
             # Ctrl+4, Ctrl+5) are invalid
@@ -395,14 +365,8 @@ class ShortcutEditor(QDialog):
         self.new_sequence = sequence
 
         conflicts = self.check_conflicts()
-        blacklist = self.new_sequence in BLACKLIST
-        individual_keys = self.new_sequence.split('+')
         if conflicts and different_sequence:
             warning_type = SEQUENCE_CONFLICT
-        elif blacklist:
-            warning_type = IN_BLACKLIST
-        elif len(individual_keys) == 2 and individual_keys[0] == 'Shift':
-            warning_type = SHIFT_BLACKLIST
         else:
             warning_type = NO_WARNING
 
@@ -690,7 +654,6 @@ class ShortcutsTable(QTableView):
 
     def adjust_cells(self):
         """Adjust column size based on contents."""
-        self.resizeRowsToContents()
         self.resizeColumnsToContents()
         fm = self.horizontalHeader().fontMetrics()
         names = [fm.width(s.name + ' '*9) for s in self.source_model.shortcuts]
