@@ -11,11 +11,10 @@ Rope introspection plugin
 import time
 import imp
 
-from spyder_kernels.utils.dochelpers import getsignaturefromtext
-
 from spyder.config.base import get_conf_path, STDERR
 from spyder.utils import encoding, programs
 from spyder.py3compat import PY2
+from spyder.utils.dochelpers import getsignaturefromtext
 from spyder.utils import sourcecode
 from spyder.utils.debug import log_last_error, log_dt
 from spyder.utils.introspection.manager import (
@@ -23,7 +22,6 @@ from spyder.utils.introspection.manager import (
 from spyder.utils.introspection.module_completion import (
     get_preferred_submodules)
 from spyder.utils.introspection.manager import ROPE_REQVER
-from spyder.utils.introspection.utils import default_info_response
 
 try:
     try:
@@ -83,9 +81,6 @@ class RopePlugin(IntrospectionPlugin):
         source_code = info['source_code']
         offset = info['position']
 
-        # Set python path into rope project
-        self.project.prefs.set('python_path', info['sys_path'])
-
         # Prevent Rope from returning import completions because
         # it can't handle them. Only Jedi can do it!
         lines = sourcecode.split_source(source_code[:offset])
@@ -94,13 +89,12 @@ class RopePlugin(IntrospectionPlugin):
           and not ';' in last_line:
             return []
 
-        if filename is not None:
-            if PY2:
-                filename = filename.encode('utf-8')
-            else:
-                # TODO: test if this is working without any further change in
-                # Python 3 with a user account containing unicode characters
-                pass
+        if PY2:
+            filename = filename.encode('utf-8')
+        else:
+            #TODO: test if this is working without any further change in
+            # Python 3 with a user account containing unicode characters
+            pass
         try:
             resource = rope.base.libutils.path_to_resource(self.project,
                                                            filename)
@@ -125,21 +119,17 @@ class RopePlugin(IntrospectionPlugin):
     def get_info(self, info):
         """Get a formatted calltip and docstring from Rope"""
         if self.project is None:
-            return default_info_response()
+            return
         filename = info['filename']
         source_code = info['source_code']
         offset = info['position']
 
-        # Set python path into rope project
-        self.project.prefs.set('python_path', info['sys_path'])
-
-        if filename is not None:
-            if PY2:
-                filename = filename.encode('utf-8')
-            else:
-                # TODO: test if this is working without any further change in
-                # Python 3 with a user account containing unicode characters
-                pass
+        if PY2:
+            filename = filename.encode('utf-8')
+        else:
+            #TODO: test if this is working without any further change in
+            # Python 3 with a user account containing unicode characters
+            pass
         try:
             resource = rope.base.libutils.path_to_resource(self.project,
                                                            filename)
@@ -211,10 +201,10 @@ class RopePlugin(IntrospectionPlugin):
                 note = 'Present in %s module' % module
 
         if not doc_text and not calltip:
-            return default_info_response()
+            return
 
         return dict(name=obj_fullname, argspec=argspec, note=note,
-                    docstring=doc_text, calltip=calltip)
+            docstring=doc_text, calltip=calltip)
 
     def get_definition(self, info):
         """Find a definition location using Rope"""
@@ -225,15 +215,12 @@ class RopePlugin(IntrospectionPlugin):
         source_code = info['source_code']
         offset = info['position']
 
-        # Set python path into rope project
-        self.project.prefs.set('python_path', info['sys_path'])
-        if filename is not None:
-            if PY2:
-                filename = filename.encode('utf-8')
-            else:
-                # TODO: test if this is working without any further change in
-                # Python 3 with a user account containing unicode characters
-                pass
+        if PY2:
+            filename = filename.encode('utf-8')
+        else:
+            #TODO: test if this is working without any further change in
+            # Python 3 with a user account containing unicode characters
+            pass
         try:
             resource = rope.base.libutils.path_to_resource(self.project,
                                                            filename)
