@@ -32,9 +32,11 @@ from spyder.config.base import (_, get_conf_path, get_image_path,
 from spyder.config.gui import get_font, get_shortcut
 from spyder.utils import icon_manager as ima
 from spyder.utils import sourcecode
+from spyder.utils.encoding import get_coding
 from spyder.utils.programs import TEMPDIR
 from spyder.utils.qthelpers import (add_actions, create_action,
                                     create_toolbutton)
+from spyder.py3compat import to_text_string
 from spyder.widgets.browser import WebView
 from spyder.widgets.mixins import SaveHistoryMixin
 from spyder.widgets.ipythonconsole import ShellWidget
@@ -158,7 +160,8 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         self.shellwidget.executing.connect(self.add_to_history)
 
         # For Mayavi to run correctly
-        self.shellwidget.executing.connect(self.set_backend_for_mayavi)
+        self.shellwidget.executing.connect(
+            self.shellwidget.set_backend_for_mayavi)
 
         # To update history after execution
         self.shellwidget.executed.connect(self.update_history)
@@ -177,6 +180,15 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         self.shellwidget.sig_kernel_restarted.connect(
             self.kernel_restarted_message)
 
+        # To restart the kernel when errors happened while debugging
+        # See issue 4003
+        self.shellwidget.sig_dbg_kernel_restart.connect(
+                self.restart_kernel)
+
+        # To correctly change Matplotlib backend interactively
+        self.shellwidget.executing.connect(
+            self.shellwidget.change_mpl_backend)
+
     def enable_stop_button(self):
         self.stop_button.setEnabled(True)
 
@@ -323,12 +335,20 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         Took this code from the qtconsole project
         Licensed under the BSD license
         """
-        message = _('Are you sure you want to restart the kernel?')
-        buttons = QMessageBox.Yes | QMessageBox.No
-        result = QMessageBox.question(self, _('Restart kernel?'),
-                                      message, buttons)
-        if result == QMessageBox.Yes:
-            sw = self.shellwidget
+        sw = self.shellwidget
+
+        # This is needed to restart the kernel without a prompt
+        # when an error in stdout corrupts the debugging process.
+        # See issue 4003
+        if not sw._input_reply_failed:
+            message = _('Are you sure you want to restart the kernel?')
+            buttons = QMessageBox.Yes | QMessageBox.No
+            result = QMessageBox.question(self, _('Restart kernel?'),
+                                          message, buttons)
+        else:
+            result = None
+
+        if result == QMessageBox.Yes or sw._input_reply_failed:
             if sw.kernel_manager:
                 if self.infowidget.isVisible():
                     self.infowidget.hide()
@@ -341,10 +361,16 @@ class ClientWidget(QWidget, SaveHistoryMixin):
                         before_prompt=True
                     )
                 else:
-                    sw.reset(clear=True)
-                    sw._append_html(_("<br>Restarting kernel...\n<hr><br>"),
-                        before_prompt=False,
-                    )
+                    sw.reset(clear=not sw._input_reply_failed)
+                    if sw._input_reply_failed:
+                        sw._append_html(_("<br>Restarting kernel because "
+                                        "an error occurred while "
+                                        "debugging\n<hr><br>"),
+                                        before_prompt=False)
+                        sw._input_reply_failed = False
+                    else:
+                        sw._append_html(_("<br>Restarting kernel...\n<hr><br>"),
+                                before_prompt=False)
             else:
                 sw._append_plain_text(
                     _('Cannot restart a kernel not started by Spyder\n'),
@@ -354,7 +380,17 @@ class ClientWidget(QWidget, SaveHistoryMixin):
     @Slot(str)
     def kernel_restarted_message(self, msg):
         """Show kernel restarted/died messages."""
-        stderr = codecs.open(self.stderr_file, 'r', encoding='utf-8').read()
+        try:
+            stderr = codecs.open(self.stderr_file, 'r',
+                                 encoding='utf-8').read()
+        except UnicodeDecodeError:
+            # This is needed since the stderr file could be encoded
+            # in something different to utf-8.
+            # See issue 4191
+            try:
+                stderr = self._read_stderr()
+            except:
+                stderr = None
 
         if stderr:
             self.show_kernel_error('<tt>%s</tt>' % stderr)
@@ -386,23 +422,6 @@ class ClientWidget(QWidget, SaveHistoryMixin):
     def update_history(self):
         self.history = self.shellwidget._history
 
-    def set_backend_for_mayavi(self, command):
-        """
-        Mayavi plots require the Qt backend, so we try to detect if one is
-        generated to change backends
-        """
-        calling_mayavi = False
-        lines = command.splitlines()
-        for l in lines:
-            if not l.startswith('#'):
-                if 'import mayavi' in l or 'from mayavi' in l:
-                    calling_mayavi = True
-                    break
-        if calling_mayavi:
-            message = _("Changing backend to Qt for Mayavi")
-            self.shellwidget._append_plain_text(message + '\n')
-            self.shellwidget.execute("%gui inline\n%gui qt")
-
     #------ Private API -------------------------------------------------------
     def _create_loading_page(self):
         """Create html page to show while the kernel is starting"""
@@ -431,3 +450,10 @@ class ClientWidget(QWidget, SaveHistoryMixin):
 
         document = self.get_control().document()
         document.contentsChange.disconnect(self._hide_loading_page)
+
+    def _read_stderr(self):
+        """Read the stderr file of the kernel."""
+        stderr_text = open(self.stderr_file, 'rb').read()
+        encoding = get_coding(stderr_text)
+        stderr = to_text_string(stderr_text, encoding)
+        return stderr
